@@ -19,17 +19,8 @@
 #include <unistd.h>
 
 #ifdef ALIGNMENT
-#ifdef __TURBOC__
-#include <mem.h>
-#else
 #include <memory.h>
 #endif
-#endif
-
-#ifdef Macintosh
-/* Macintoshes need 32K segments, else barfage ensues */
-#pragma segment seg2a
-#endif /*Macintosh*/
 
 /*  Custom configuration.  If the tag CUSTOM has been defined (usually on
     the compiler call line), we include the file "atlcfig.h", which may
@@ -45,6 +36,7 @@
     defined.  Otherwise, we automatically enable all the subpackages.  */
 
 #ifndef INDIVIDUALLY
+/* #define ANSIFLOAT */     	      /* Synonyms for ANSI FORTH-94 floating point */
 #define ARRAY			      /* Array subscripting words */
 #define BREAK			      /* Asynchronous break facility */
 #define COMPILERW		      /* Compiler-writing words */
@@ -92,7 +84,7 @@
 
 typedef enum {False = 0, True = 1} Boolean;
 
-#define EOS     '\0'                  /* End of string characters */
+#define EOS     '\0'                  /* End of string character */
 
 #define V	(void)		      /* Force result to void */
 
@@ -111,11 +103,15 @@ typedef enum {False = 0, True = 1} Boolean;
 
 #define ELEMENTS(array) (sizeof(array)/sizeof((array)[0]))
 
+/*  Black art definition used to verify sizes of types at compile time  */
+
+#define MEMORY_MODEL_ERROR(condition) ((void)sizeof(char[1 - 2*!!(condition)]))
+
 /*  Globals visible to calling programs  */
 
 atl_int atl_stklen = 100;	      /* Evaluation stack length */
 atl_int atl_rstklen = 100;	      /* Return stack length */
-atl_int atl_heaplen = 1000;	      /* Heap length */
+atl_int atl_heaplen = 2000;	      /* Heap length */
 atl_int atl_ltempstr = 256;	      /* Temporary string buffer length */
 atl_int atl_ntempstr = 4;	      /* Number of temporary string buffers */
 
@@ -220,10 +216,8 @@ static Boolean broken = False;	      /* Asynchronous break received */
 #endif
 
 #ifdef COPYRIGHT
-#ifndef HIGHC
 #ifndef lint
 static
-#endif
 #endif
        char copyright[] = "ATLAST: This program is in the public domain.";
 #endif
@@ -231,7 +225,7 @@ static
 /* The following static cells save the compile addresses of words
    generated by the compiler.  They are looked up immediately after
    the dictionary is created.  This makes the compiler much faster
-   since it doesn't have to look up internally-reference words, and,
+   since it doesn't have to look up internally-referenced words, and,
    far more importantly, keeps it from being spoofed if a user redefines
    one of the words generated by the compiler.	*/
 
@@ -420,15 +414,6 @@ static int token(cp)
 	    char tc;
 	    char *tcp;
 
-#ifdef OS2
-	    /* Compensate for error in OS/2 sscanf() library function */
-            if ((tokbuf[0] == '-') &&
-		!(isdigit(tokbuf[1]) ||
-                    (((tokbuf[1] == 'x') || (tokbuf[1] == 'X')) &&
-			isxdigit(tokbuf[2])))) {
-		return TokWord;
-	    }
-#endif /* OS2 */
 #ifdef USE_SSCANF
             if (sscanf(tokbuf, "%li%c", &tokint, &tc) == 1)
 		return TokInt;
@@ -468,8 +453,6 @@ static dictword *lookup(tkname)
     return dw;
 }
 
-/* Gag me with a spoon!  Does no compiler but Turbo support
-   #if defined(x) || defined(y) ?? */
 #ifdef EXPORT
 #define FgetspNeeded
 #endif
@@ -1160,11 +1143,11 @@ prim P_strform()		      /* Format integer using sprintf() */
 #ifdef REAL
 prim P_fstrform()		      /* Format real using sprintf() */
 {                                     /* rvalue "%6.2f" str -- */
-    Sl(4);
+    Sl(2 + Realsize);
     Hpc(S0);
     Hpc(S1);
-    V sprintf((char *) S0, (char *) S1, REAL1);
-    Npop(4);
+    V sprintf((char *) S0, (char *) S1, REAL2);
+    Npop(2 + Realsize);
 }
 #endif /* REAL */
 
@@ -1826,13 +1809,6 @@ prim P_rfetch() 		      /* Fetch top item from return stack */
     Push = (stackitem) R0;
 }
 
-#ifdef Macintosh
-/* This file creates more than 32K of object code on the Mac, which causes
-   MPW to barf.  So, we split it up into two code segments of <32K at this
-   point. */
-#pragma segment TOOLONG
-#endif /* Macintosh */
-
 /*  Double stack manipulation items  */
 
 #ifdef DOUBLE
@@ -2826,6 +2802,14 @@ static struct primfcn primt[] = {
     {"0F.", P_fdot},
     {"0FLOAT", P_float},
     {"0FIX", P_fix},
+#ifdef ANSIFLOAT
+    {"0FVARIABLE", P_variable},
+    {"0FCONSTANT", P_constant},
+    {"0F!", P_bang},
+    {"0F@", P_at},
+    {"0FSWAP", P_swap},
+    {"0FDUP", P_dup},
+#endif /* ANSIFLOAT */
 #ifdef MATH
     {"0ACOS", P_acos},
     {"0ASIN", P_asin},
@@ -2838,6 +2822,19 @@ static struct primfcn primt[] = {
     {"0SIN", P_sin},
     {"0SQRT", P_sqrt},
     {"0TAN", P_tan},
+#ifdef ANSIFLOAT
+    {"0FACOS", P_acos},
+    {"0FASIN", P_asin},
+    {"0FATAN", P_atan},
+    {"0FATAN2", P_atan2},
+    {"0FCOS", P_cos},
+    {"0FEXP", P_exp},
+    {"0FLOG", P_log},
+    {"0FPOW", P_pow},
+    {"0FSIN", P_sin},
+    {"0FSQRT", P_sqrt},
+    {"0FTAN", P_tan},
+#endif /* ANSIFLOAT */
 #endif /* MATH */
 #endif /* REAL */
 
@@ -3182,6 +3179,21 @@ static void exword(wp)
 
 void atl_init()
 {
+
+    /* If any of the following three lines of code produce errors,
+       you are probably trying to build on an architecture which
+       violates the fundamental reuirement of 64-bit ATLAST that
+       stack items, pointers, and real numbers are all 8 byte, 64-bit
+       values.  If this is the case and you can't fix the problem by
+       changing compiler memory model options, it's best to revert
+       to the 32-bit version of ATLAST, which can be built on most
+       systems (including 64-bit systems) by compiling and linking
+       in 32-bit mode. */
+    
+    MEMORY_MODEL_ERROR(sizeof(stackitem) != 8);
+    MEMORY_MODEL_ERROR(sizeof(stackitem *) != 8);
+    MEMORY_MODEL_ERROR(sizeof(atl_real) != 8);
+
     if (dict == NULL) {
 	atl_primdef(primt);	      /* Define primitive words */
 	dictprot = dict;	      /* Set protected mark in dictionary */
