@@ -29,9 +29,31 @@ prim phhmmss()
     Push = lt->tm_sec;
 }
 
+prim pleibniz()
+{
+    long nterms;
+    double sum = 0.0,
+           numer = 1.0,
+           denom = 1.0;
+
+    Sl(1);
+    nterms = S0;
+    Pop;
+
+    So(Realsize);
+    Push = 0;
+    while (nterms-- > 0) {
+        sum += numer / denom;
+        numer = -numer;
+        denom += 2.0;
+    }
+    SREAL0(sum * 4.0);
+}
+
 static struct primfcn timep[] = {
     {"0TIME",   ptime},
     {"0HHMMSS", phhmmss},
+    {"0LEIBNIZ", pleibniz},
     {NULL,      (codeptr) 0}
 };
 
